# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

class Link(object):

    def __init__(self, controller_path=None, controller_args={}, label=None,
                 icon=None):
        self.controller_path = controller_path
        self.controller_args = controller_args
        self.label = label
        self.icon = icon

class DeviceLink(Link):

    def __init__(self, udi, *args, **kwargs):
        super(DeviceLink, self).__init__(*args, **kwargs)
        self.udi = udi
        
